import React from 'react';
import { useNavigate } from 'react-router-dom';
import { ArrowPathIcon } from '@heroicons/react/24/outline';
import Button from './Button';
import { openCandApi } from '../api/openCandApi';

interface RandomCandButtonProps {
  className?: string;
  hasAnimation?: boolean;
}

const RandomCandButton: React.FC<RandomCandButtonProps> = ({ 
  className = '', 
  hasAnimation = false 
}) => {
  const navigate = useNavigate();

  const handleRandomCandidate = async () => {
    try {
      const randomCandidate = await openCandApi.getRandomCandidate();
      navigate(`/candidato/${randomCandidate.idCandidato}`);
    } catch (error) {
      console.error('Erro ao buscar candidato aleatório:', error);
      // You might want to show a toast notification or error message to the user
    }
  };

  return (
    <Button 
      onClick={handleRandomCandidate} 
      className={`flex items-center ${className}`}
      hasAnimation={hasAnimation}
    >
      <ArrowPathIcon className="h-4 w-4 mr-2" />
      Candidato aleatório
    </Button>
  );
};

export default RandomCandButton;
